==> lettuce-core-5.2.2.RELEASE-sources.jar: io/lettuce/core/dynamic/support/ParameterNameDiscoverer.java <==
/*
 * Copyright 2011-2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.lettuce.core.dynamic.support;

import java.lang.reflect.Constructor;
import java.lang.reflect.Method;

/**
 * Interface to discover parameter names for methods and constructors.
 *
 * <p>
 * Parameter name discovery is not always possible, but various strategies are available to try, such as looking for debug
 * information that may have been emitted at compile time, and looking for argname annotation values.
 */
public interface ParameterNameDiscoverer {

    /**
     * Return parameter names for this method, or {@code null} if they cannot be determined.
     *
     * @param method method to find parameter names for
     * @return an array of parameter names if the names can be resolved, or {@code null} if they cannot
     */
    String[] getParameterNames(Method method);

    /**
     * Return parameter names for this constructor, or {@code null} if they cannot be determined.
     *
     * @param ctor constructor to find parameter names for
     * @return an array of parameter names if the names can be resolved, or {@code null} if they cannot
     */
    String[] getParameterNames(Constructor<?> ctor);

}

==> lettuce-core-5.3.3.RELEASE-sources.jar: io/lettuce/core/dynamic/support/ParameterNameDiscoverer.java <==
/*
 * Copyright 2011-2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.lettuce.core.dynamic.support;

import java.lang.reflect.Constructor;
import java.lang.reflect.Method;

/**
 * Interface to discover parameter names for methods and constructors.
 *
 * <p>
 * Parameter name discovery is not always possible, but various strategies are available to try, such as looking for debug
 * information that may have been emitted at compile time, and looking for argname annotation values.
 */
public interface ParameterNameDiscoverer {

    /**
     * Return parameter names for this method, or {@code null} if they cannot be determined.
     *
     * @param method method to find parameter names for.
     * @return an array of parameter names if the names can be resolved, or {@code null} if they cannot.
     */
    String[] getParameterNames(Method method);

    /**
     * Return parameter names for this constructor, or {@code null} if they cannot be determined.
     *
     * @param ctor constructor to find parameter names for.
     * @return an array of parameter names if the names can be resolved, or {@code null} if they cannot.
     */
    String[] getParameterNames(Constructor<?> ctor);

}
